# stsci.skypac

[![Documentation Status](https://readthedocs.org/projects/stsci-skypac/badge/?version=latest)](http://stsci-skypac.readthedocs.io/en/latest/?badge=latest)
[![build](https://github.com/spacetelescope/stsci.skypac/actions/workflows/publish-to-pypi.yml/badge.svg)](https://github.com/spacetelescope/stsci.skypac/actions/workflows/publish-to-pypi.yml)
[![PyPI Status](https://img.shields.io/pypi/v/stsci.skypac.svg)](https://pypi.org/project/stsci.skypac/)
[![Powered by Astropy Badge](http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat)](http://www.astropy.org/)

Sky matching for image mosaic.
